#!/bin/bash
# test we are root
if [ "$(id -u)" != "0" ]; then
   echo "run as root now exitting"
   exit 1
fi

CFLAGS="gcc -flto -fuse-linker-plugin -mtune=generic -Os -pipe"
CXX="g++ -flto -fuse-linker-plugin -mtune=generic -Os -pipe -fno-exceptions -fno-rtti" 

# in case checking slurp after grim
rm -rf *zip

P=slurp
V=1.2.0
SRC=$P-$V
USER=`cat /etc/sysconfig/tcuser`
LIST="compiletc submitqc meson wayland-dev cairo-dev scdoc-dev "
for Z in $LIST 
    do 
    su -c "tce-load -i $Z" $USER
done

cd /tmp
su -c "/usr/local/bin/wget -nc --no-check-certificate \
https://github.com/emersion/$P/archive/v$V.zip    " $USER
unzip v$V*zip
cd $SRC
# meson defaults to usr/local
meson --strip build
ninja -C build
touch /tmp/mark
ninja -C build install
cd /tmp

# main
######
mkdir -p $P/usr/local/share/doc/$P
cp $SRC/LICENSE  $P/usr/local/share/doc/$P/

mkdir -p $P/usr/local/bin
mv /usr/local/bin/$P* $P/usr/local/bin

# doc
#####
mkdir -p $P-doc/usr/local/share/man/man1
cp $SRC/build/*.1 $P-doc/usr/local/share/man/man1/
mkdir -p $P-doc/usr/local/share/doc/$P
cp $SRC/LICENSE  $P-doc/usr/local/share/doc/$P/

# TCZ them
#######
LIST="$P $P-doc "
for Z in $LIST
do
	mksquashfs $Z $Z.tcz
	md5sum $Z.tcz > $Z.tcz.md5.txt
	cd $Z
	find usr -not -type d > /tmp/$Z.tcz.list
        sed 's|usr|/usr|g' -i /tmp/$Z.tcz.list
	cd /tmp
done

ls -hal

echo 'libjpeg-turbo.tcz
cairo.tcz
grim.tcz' > $P.tcz.dep

echo 'man-db.tcz' > $P-doc.tcz.dep

echo 'Title:          slurp.tcz 
Description:    Select a region in a sway for screenshots 
Version:        1.2.0
Author:         emersion
Original-site:  https://github.com/emersion/slurp
Copying-policy: Accompanied 
Size:           16K		
Extension_by:   aus9 at gmx dot com
Tags:           sway screen capture
Comments:       Can only be used on sway.  slurp is a command-line app to 
                select a region inside sway and used with grim to take a screenshot.
                grim can not escape its current window, but slurp can.

                $ slurp | grim 1.png
                (for a RH mouse user, Left click top left corner of your desired selection
                hold mouse button down....move mouse to bottom RH corner of selection.
                Release button.....screenshot taken)

                man page offer more options

                Compiled for 10x.1
Change-log:     2019/06/16 first version 
Current:        2019/06/16  ' > $P.tcz.info

echo 'Title:          slurp-doc.tcz 
Description:    docs for slurp
Version:        1.2.0
Author:         emersion
Original-site:  https://github.com/emersion/slurp
Copying-policy: Accompanied 
Size:           4.0K	
Extension_by:   aus9 at gmx dot com
Tags:           sway man
Comments:       docs  

                Compiled for 10.1 
Change-log:     2019/06/16 first version 
Current:        2019/06/16  ' > $P-doc.tcz.info

submitqc --libs
